@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id$
+# $Id: Cursor.pm 6484 2011-04-21 09:25:12Z powergnom $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Cursor> - specification for class Cursor
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 our %CHILDREN = ('cursor' => {'desc'     => 1,
                               'metadata' => 1,
@@ -29,16 +29,16 @@ our %ATTR_VAL = ('cursor' => {'externalResourcesRequired' => {'optional' => 1,
                                                               'regex'    => qr/^(?:false|true)$/},
                               'id'                        => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => $RE_XML{p_NAME}},
                               'requiredExtensions'        => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'requiredFeatures'          => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'systemLanguage'            => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'x'                         => {'optional' => 1,
                                                               'type'     => SCALAR,
                                                               'regex'    => $RE_LENGTH{p_A_LENGTH}},
@@ -47,34 +47,34 @@ our %ATTR_VAL = ('cursor' => {'externalResourcesRequired' => {'optional' => 1,
                                                               'regex'    => qr/^(?:onLoad)$/},
                               'xlink:arcrole'             => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'xlink:href'                => {'optional' => 0,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'xlink:role'                => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'xlink:show'                => {'default'  => 'other',
                                                               'type'     => SCALAR,
                                                               'regex'    => qr/^(?:other)$/},
                               'xlink:title'               => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'xlink:type'                => {'default'  => 'simple',
                                                               'type'     => SCALAR,
                                                               'regex'    => qr/^(?:simple)$/},
                               'xml:base'                  => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'xml:lang'                  => {'optional' => 1,
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => $RE_XML{p_NMTOKEN}},
                               'xml:space'                 => {'optional' => 1,
                                                               'type'     => SCALAR,
                                                               'regex'    => qr/^(?:default|preserve)$/},
                               'xmlns:xlink'               => {'default'  => 'http://www.w3.org/1999/xlink',
                                                               'type'     => SCALAR,
-                                                              'regex'    => qr//},
+                                                              'regex'    => qr/.?/},
                               'y'                         => {'optional' => 1,
                                                               'type'     => SCALAR,
                                                               'regex'    => $RE_LENGTH{p_A_LENGTH}}});
@@ -106,7 +106,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Lutz Gehlen.
+Copyright 2010-2011 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either: the GNU General Public License as
