@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id: Hyperlink.pm 6211 2010-06-15 04:21:13Z mullet $
+# $Id: Hyperlink.pm 6484 2011-04-21 09:25:12Z powergnom $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Hyperlink> - specification for class Hyperlink
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 our %CHILDREN = ('a' => {'a'                => 1,
                          'altGlyphDef'      => 1,
@@ -65,16 +65,16 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:auto|baseline|before\-edge|text\-before\-edge|middle|central|after\-edge|text\-after\-edge|ideographic|alphabetic|hanging|mathematical|inherit)$/},
                          'baseline-shift'               => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'class'                        => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'clip'                         => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'clip-path'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'clip-rule'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
@@ -89,13 +89,13 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
                          'color-profile'                => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'color-rendering'              => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                          'cursor'                       => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'direction'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:ltr|rtl|inherit)$/},
@@ -107,7 +107,7 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:auto|use\-script|no\-change|reset\-size|ideographic|alphabetic|hanging|mathematical|central|middle|text\-after\-edge|text\-before\-edge|inherit)$/},
                          'enable-background'            => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'externalResourcesRequired'    => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:false|true)$/},
@@ -122,22 +122,22 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                          'filter'                       => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'flood-color'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'flood-opacity'                => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                          'font-family'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'font-size'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'font-size-adjust'             => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'font-stretch'                 => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:normal|wider|narrower|ultra\-condensed|extra\-condensed|condensed|semi\-condensed|semi\-expanded|expanded|extra\-expanded|ultra\-expanded|inherit)$/},
@@ -152,67 +152,67 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:normal|bold|bolder|lighter|100|200|300|400|500|600|700|800|900|inherit)$/},
                          'glyph-orientation-horizontal' => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'glyph-orientation-vertical'   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'id'                           => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => $RE_XML{p_NAME}},
                          'image-rendering'              => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                          'kerning'                      => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'letter-spacing'               => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'lighting-color'               => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'marker-end'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'marker-mid'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'marker-start'                 => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'mask'                         => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onactivate'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onclick'                      => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onfocusin'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onfocusout'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onload'                       => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onmousedown'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onmousemove'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onmouseout'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onmouseover'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'onmouseup'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'opacity'                      => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -224,16 +224,16 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:visiblePainted|visibleFill|visibleStroke|visible|painted|fill|stroke|all|none|inherit)$/},
                          'requiredExtensions'           => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'requiredFeatures'             => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'shape-rendering'              => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:auto|optimizeSpeed|crispEdges|geometricPrecision|inherit)$/},
                          'stop-color'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'stop-opacity'                 => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -263,19 +263,19 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/$RE_LENGTH{p_A_LENGTH}|^inherit$/},
                          'style'                        => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'systemLanguage'               => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'target'                       => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => $RE_XML{p_NMTOKEN}},
                          'text-anchor'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:start|middle|end|inherit)$/},
                          'text-decoration'              => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'text-rendering'               => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:auto|optimizeSpeed|optimizeLegibility|geometricPrecision|inherit)$/},
@@ -290,7 +290,7 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:visible|hidden|inherit)$/},
                          'word-spacing'                 => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'writing-mode'                 => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:lr\-tb|rl\-tb|tb\-rl|lr|rl|tb|inherit)$/},
@@ -299,34 +299,34 @@ our %ATTR_VAL = ('a' => {'alignment-baseline'           => {'optional' => 1,
                                                             'regex'    => qr/^(?:onRequest)$/},
                          'xlink:arcrole'                => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'xlink:href'                   => {'optional' => 0,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'xlink:role'                   => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'xlink:show'                   => {'default'  => 'replace',
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:new|replace)$/},
                          'xlink:title'                  => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'xlink:type'                   => {'default'  => 'simple',
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:simple)$/},
                          'xml:base'                     => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => qr/.?/},
                          'xml:lang'                     => {'optional' => 1,
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//},
+                                                            'regex'    => $RE_XML{p_NMTOKEN}},
                          'xml:space'                    => {'optional' => 1,
                                                             'type'     => SCALAR,
                                                             'regex'    => qr/^(?:default|preserve)$/},
                          'xmlns:xlink'                  => {'default'  => 'http://www.w3.org/1999/xlink',
                                                             'type'     => SCALAR,
-                                                            'regex'    => qr//}});
+                                                            'regex'    => qr/.?/}});
 
 our %ATTR_HINTS = ('a' => {'color'        => {'color'  => 1},
                            'fill'         => {'color'  => 1},
@@ -357,7 +357,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Lutz Gehlen.
+Copyright 2010-2011 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either: the GNU General Public License as
